==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/KatUslCzynnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class KatUslCzynnosc extends GenericDPSObject {
    /**
     * KAT_USL_CZYNNOSC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * KAT_USL_CZYNNOSC.KATEGORIA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kategoriaId;

    /**
     * KAT_USL_CZYNNOSC.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * KAT_USL_CZYNNOSC.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * KAT_USL_CZYNNOSC.KOLEJNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kolejnosc;

    /**
     * KAT_USL_CZYNNOSC.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * KAT_USL_CZYNNOSC.OPIS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String opis;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KAT_USL_CZYNNOSC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KAT_USL_CZYNNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KAT_USL_CZYNNOSC.KATEGORIA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKategoriaId() {
        return kategoriaId;
    }

    /**
     * KAT_USL_CZYNNOSC.KATEGORIA_ID
     *
     * @param kategoriaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKategoriaId(Long kategoriaId) {
        this.kategoriaId = kategoriaId;
    }

    /**
     * @return KAT_USL_CZYNNOSC.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * KAT_USL_CZYNNOSC.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return KAT_USL_CZYNNOSC.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * KAT_USL_CZYNNOSC.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return KAT_USL_CZYNNOSC.KOLEJNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * KAT_USL_CZYNNOSC.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @return KAT_USL_CZYNNOSC.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * KAT_USL_CZYNNOSC.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return KAT_USL_CZYNNOSC.OPIS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getOpis() {
        return opis;
    }

    /**
     * KAT_USL_CZYNNOSC.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KatUslCzynnosc other = (KatUslCzynnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKategoriaId() == null ? other.getKategoriaId() == null : this.getKategoriaId().equals(other.getKategoriaId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKategoriaId() == null) ? 0 : getKategoriaId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", kategoriaId=").append(kategoriaId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opis=").append(opis);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/KatUslCzynnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class KatUslCzynnosc extends GenericDPSObject {
    /**
     * KAT_USL_CZYNNOSC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * KAT_USL_CZYNNOSC.KATEGORIA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kategoriaId;

    /**
     * KAT_USL_CZYNNOSC.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * KAT_USL_CZYNNOSC.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * KAT_USL_CZYNNOSC.KOLEJNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kolejnosc;

    /**
     * KAT_USL_CZYNNOSC.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * KAT_USL_CZYNNOSC.OPIS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String opis;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KAT_USL_CZYNNOSC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KAT_USL_CZYNNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KAT_USL_CZYNNOSC.KATEGORIA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKategoriaId() {
        return kategoriaId;
    }

    /**
     * KAT_USL_CZYNNOSC.KATEGORIA_ID
     *
     * @param kategoriaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKategoriaId(Long kategoriaId) {
        this.kategoriaId = kategoriaId;
    }

    /**
     * @return KAT_USL_CZYNNOSC.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * KAT_USL_CZYNNOSC.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return KAT_USL_CZYNNOSC.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * KAT_USL_CZYNNOSC.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return KAT_USL_CZYNNOSC.KOLEJNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * KAT_USL_CZYNNOSC.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @return KAT_USL_CZYNNOSC.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * KAT_USL_CZYNNOSC.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return KAT_USL_CZYNNOSC.OPIS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getOpis() {
        return opis;
    }

    /**
     * KAT_USL_CZYNNOSC.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KatUslCzynnosc other = (KatUslCzynnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKategoriaId() == null ? other.getKategoriaId() == null : this.getKategoriaId().equals(other.getKategoriaId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKategoriaId() == null) ? 0 : getKategoriaId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", kategoriaId=").append(kategoriaId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", opis=").append(opis);
        sb.append("]");
        return sb.toString();
    }
}
